@@ -19,6 +19,7 @@
 #define OVER_VIEW_WIDGET_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QBitmap>
@@ -42,24 +43,23 @@ namespace Kwave
 {
 
     class SignalManager;
-    class Track;
 
-    class Q_DECL_EXPORT OverViewWidget: public Kwave::ImageView
+    class LIBKWAVEGUI_EXPORT OverViewWidget: public Kwave::ImageView
     {
         Q_OBJECT
     public:
         /** Constructor */
         explicit OverViewWidget(Kwave::SignalManager &signal,
-                                QWidget *parent = Q_NULLPTR);
+                                QWidget *parent = nullptr);
 
         /** Destructor */
-        virtual ~OverViewWidget() Q_DECL_OVERRIDE;
+        ~OverViewWidget() override;
 
         /** minimum size of the widget, @see QWidget::minimumSize() */
         virtual QSize minimumSize() const;
 
         /** optimal size for the widget, @see QWidget::sizeHint() */
-        virtual QSize sizeHint() const Q_DECL_OVERRIDE;
+        QSize sizeHint() const override;
 
     public slots:
 
@@ -96,19 +96,19 @@ namespace Kwave
     protected:
 
         /** refreshes the bitmap when resized */
-        virtual void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
+        void resizeEvent(QResizeEvent *) override;
 
         /**
          * On mouse move:
          * move the current viewport center to the clicked position.
          */
-        virtual void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+        void mouseMoveEvent(QMouseEvent *) override;
 
         /**
          * On single-click with the left mouse button:
          * move the current viewport center to the clicked position.
          */
-        virtual void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
+        void mousePressEvent(QMouseEvent *) override;
 
         /**
          * On double click with the left mouse button, without shift:
@@ -119,7 +119,7 @@ namespace Kwave
          * The same as above, but zoom out instead of in
          * (by sending "view:zoom_out()").
          */
-        virtual void mouseDoubleClickEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        void mouseDoubleClickEvent(QMouseEvent *e) override;
 
     protected slots:
 
@@ -181,10 +181,10 @@ namespace Kwave
             explicit WorkerThread(Kwave::OverViewWidget *widget);
 
             /** destructor */
-            virtual ~WorkerThread() Q_DECL_OVERRIDE;
+            ~WorkerThread() override;
 
             /** thread function that calls calculateBitmap() */
-            virtual void run() Q_DECL_OVERRIDE;
+            void run() override;
 
         private:
 
