@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <errno.h>
 #include <math.h>
@@ -45,12 +44,9 @@
 
 #include "libkwave/ClipBoard.h"
 #include "libkwave/LabelList.h"
-#include "libkwave/SignalManager.h"
-#include "libkwave/String.h"
 #include "libkwave/Track.h"
 #include "libkwave/Utils.h"
 
-#include "libgui/SignalView.h"
 #include "libgui/SignalWidget.h"
 #include "libgui/TrackPixmap.h"
 #include "libgui/TrackView.h"
@@ -197,8 +193,10 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     QAction *action;
     action = context_menu->addAction(
         QIcon::fromTheme(_("edit-undo")),
-        i18n("&Undo"), this, SLOT(contextMenuEditUndo()),
-        QKeySequence::StandardKey::Undo);
+        i18n("&Undo"),
+        QKeySequence::StandardKey::Undo,
+        this,
+        SLOT(contextMenuEditUndo()));
     Q_ASSERT(action);
     if (!action) return;
     if (!m_signal_manager->canUndo())
@@ -207,8 +205,10 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     // redo
     action = context_menu->addAction(
         QIcon::fromTheme(_("edit-redo")),
-        i18n("&Redo"), this, SLOT(contextMenuEditRedo()),
-        QKeySequence::StandardKey::Redo);
+        i18n("&Redo"),
+        QKeySequence::StandardKey::Redo,
+        this,
+        SLOT(contextMenuEditRedo()));
     Q_ASSERT(action);
     if (!action) return;
     if (!m_signal_manager->canRedo())
@@ -218,16 +218,22 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     // cut/copy/paste
     QAction *action_cut = context_menu->addAction(
         QIcon::fromTheme(_("edit-cut")),
-        i18n("Cu&t"), this, SLOT(contextMenuEditCut()),
-        QKeySequence::StandardKey::Cut);
+        i18n("Cu&t"),
+        QKeySequence::StandardKey::Cut,
+        this,
+        SLOT(contextMenuEditCut()));
     QAction *action_copy = context_menu->addAction(
         QIcon::fromTheme(_("edit-copy")),
-        i18n("&Copy"), this, SLOT(contextMenuEditCopy()),
-        QKeySequence::StandardKey::Copy);
+        i18n("&Copy"),
+        QKeySequence::StandardKey::Copy,
+        this,
+        SLOT(contextMenuEditCopy()));
     QAction *action_paste = context_menu->addAction(
         QIcon::fromTheme(_("edit-paste")),
-        i18n("&Paste"), this, SLOT(contextMenuEditPaste()),
-        QKeySequence::StandardKey::Paste);
+        i18n("&Paste"),
+        QKeySequence::StandardKey::Paste,
+        this,
+        SLOT(contextMenuEditPaste()));
     context_menu->addSeparator();
     if (action_cut)   action_cut->setEnabled(have_selection);
     if (action_copy)  action_copy->setEnabled(have_selection);
@@ -256,32 +262,36 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 
     // Selection / &Expand to labels
     QAction *action_select_expand_to_labels = submenu_select->addAction(
-        i18n("&Expand to Labels"), this,
-        SLOT(contextMenuSelectionExpandToLabels()), Qt::Key_E);
+        i18n("&Expand to Labels"),
+        Qt::Key_E,
+        this,
+        SLOT(contextMenuSelectionExpandToLabels()));
     Q_ASSERT(action_select_expand_to_labels);
     if (!action_select_expand_to_labels) return;
     action_select_expand_to_labels->setEnabled(have_labels);
 
     // Selection / to next labels
     QAction *action_select_next_labels = submenu_select->addAction(
-        i18n("To Next Labels"), this,
-        SLOT(contextMenuSelectionNextLabels()),
-        Qt::SHIFT + Qt::CTRL + Qt::Key_N);
+        i18n("To Next Labels"),
+        Qt::SHIFT | Qt::CTRL | Qt::Key_N,
+        this,
+        SLOT(contextMenuSelectionNextLabels()));
     Q_ASSERT(action_select_next_labels);
     if (!action_select_next_labels) return;
     action_select_next_labels->setEnabled(have_labels);
 
     // Selection / to previous labels
     QAction *action_select_prev_labels = submenu_select->addAction(
-        i18n("To Previous Labels"), this,
-        SLOT(contextMenuSelectionPrevLabels()),
-        Qt::SHIFT + Qt::CTRL + Qt::Key_P);
+        i18n("To Previous Labels"),
+        Qt::SHIFT | Qt::CTRL | Qt::Key_P,
+        this,
+        SLOT(contextMenuSelectionPrevLabels()));
     Q_ASSERT(action_select_prev_labels);
     if (!action_select_prev_labels) return;
     action_select_prev_labels->setEnabled(have_labels);
 
     // find out whether there was a click within a signal view
-    QSharedPointer<Kwave::ViewItem> item(Q_NULLPTR);
+    QSharedPointer<Kwave::ViewItem> item(nullptr);
     foreach (QPointer<Kwave::SignalView> view, m_views) {
         // map the rect of the view to our coordinate system
         const QRect view_rect = QRect(
@@ -547,6 +557,7 @@ void Kwave::SignalWidget::insertView(Kwave::SignalView *view,
             m_lower_dock->addWidget(view);
             Q_ASSERT(!controls);
             break;
+        DEFAULT_IMPOSSIBLE;
     }
 
     // insert the view into the list of views
@@ -586,7 +597,7 @@ void Kwave::SignalWidget::slotTrackInserted(unsigned int index,
     if (!track) return;
 
     // create a container widget for the track controls
-    QWidget *controls = new(std::nothrow) QWidget(Q_NULLPTR);
+    QWidget *controls = new(std::nothrow) QWidget(nullptr);
     Q_ASSERT(controls);
     if (!controls) return;
 
@@ -668,7 +679,7 @@ void Kwave::SignalWidget::updateMinimumHeight()
         int h = 0;
         for (int col = 0; col < cols; col++) {
             QLayoutItem *item = m_layout.itemAtPosition(row, col);
-            QWidget *widget = (item) ? item->widget() : Q_NULLPTR;
+            QWidget *widget = (item) ? item->widget() : nullptr;
             if (widget) {
                 int min_height = widget->minimumSize().height();
                 if (min_height > h) h = min_height;
@@ -691,3 +702,5 @@ void Kwave::SignalWidget::updateMinimumHeight()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SignalWidget.cpp"
