@@ -15,10 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
-#include <QCursor>
-#include <QObject>
 
 #include <KLocalizedString>
 
@@ -46,14 +43,14 @@ Kwave::ViewItem::Flags Kwave::ViewItem::flags() const
 //***************************************************************************
 QString Kwave::ViewItem::toolTip(sample_index_t &ofs)
 {
-    Q_UNUSED(ofs);
+    Q_UNUSED(ofs)
     return QString();
 }
 
 //***************************************************************************
 void Kwave::ViewItem::appendContextMenu(QMenu *parent)
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
 }
 
 //***************************************************************************
@@ -65,7 +62,7 @@ QCursor Kwave::ViewItem::mouseCursor() const
 //***************************************************************************
 void Kwave::ViewItem::moveTo(const QPoint &mouse_pos)
 {
-    Q_UNUSED(mouse_pos);
+    Q_UNUSED(mouse_pos)
 }
 
 //***************************************************************************
@@ -80,3 +77,5 @@ void Kwave::ViewItem::done()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_ViewItem.cpp"
