@@ -19,6 +19,7 @@
 #define FILE_PROGRESS_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QDialog>
@@ -30,15 +31,13 @@
 
 class QCloseEvent;
 class QGridLayout;
-class QLabel;
 class QProgressBar;
 class QResizeEvent;
-class KProgress;
 
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT FileProgress: public QDialog
+    class LIBKWAVE_EXPORT FileProgress: public QDialog
     {
         Q_OBJECT
     public:
@@ -58,7 +57,7 @@ namespace Kwave
             unsigned int tracks);
 
         /** Destructor */
-        virtual ~FileProgress() Q_DECL_OVERRIDE {}
+        ~FileProgress() override {}
 
         /**
          * Returns true if the dialog is unusable or the user
@@ -109,12 +108,12 @@ namespace Kwave
          * Fits again the URL label on resize events.
          * @see fitUrlLabel()
          */
-        virtual void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
+        void resizeEvent(QResizeEvent *) override;
 
         /**
          * Called if the window is to be closed.
          */
-        virtual void closeEvent(QCloseEvent *e) Q_DECL_OVERRIDE;
+        void closeEvent(QCloseEvent *e) override;
 
         /**
          * Fits the URL text into the available area, with
