@@ -19,6 +19,7 @@
 #define MESSAGE_BOX_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QObject>
@@ -32,7 +33,7 @@ class QWidget;
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT MessageBox: public QObject
+    class LIBKWAVE_EXPORT MessageBox: public QObject
     {
     Q_OBJECT
 
@@ -103,7 +104,7 @@ namespace Kwave
             const QString &dontAskAgainName = QString());
 
         /** Destructor */
-        virtual ~MessageBox();
+        ~MessageBox() override;
 
         /** returns the return value of the KMessageBox */
         virtual int retval() const;
@@ -163,7 +164,7 @@ namespace Kwave
              * thread and deleteLater() is called. This calls the "show()"
              * method of the Kwave::MessageBox in a safe context.
              */
-            virtual ~Trigger();
+            virtual ~Trigger() override;
 
         private:
 
