@@ -19,6 +19,7 @@
 #define SAMPLE_ARRAY_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QSharedData>
@@ -33,7 +34,7 @@ namespace Kwave
      * array with sample_t, for use in Kwave::SampleSource, Kwave::SampleSink
      * and other streaming classes.
      */
-    class Q_DECL_EXPORT SampleArray
+    class LIBKWAVE_EXPORT SampleArray
     {
     public:
 
@@ -53,14 +54,14 @@ namespace Kwave
         /** returns a const pointer to the raw data (non-mutable) */
         inline const sample_t * constData() const
         {
-            if (Q_UNLIKELY(!m_storage)) return Q_NULLPTR;
+            if (Q_UNLIKELY(!m_storage)) return nullptr;
             return m_storage->m_data;
         }
 
         /** returns a pointer to the raw data (mutable) */
         inline sample_t *data() /* __attribute__((deprecated)) <- for debug */
         {
-            if (Q_UNLIKELY(!m_storage)) return Q_NULLPTR;
+            if (Q_UNLIKELY(!m_storage)) return nullptr;
             return m_storage->m_data;
         }
 
