@@ -19,6 +19,7 @@
 #define SAMPLE_FIFO_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -30,7 +31,7 @@
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT SampleFIFO
+    class LIBKWAVE_EXPORT SampleFIFO
     {
     public:
         /** Constructor */
@@ -39,6 +40,9 @@ namespace Kwave
         /** copy constructor */
         SampleFIFO(const SampleFIFO &other);
 
+        /** copy assignment operator */
+        SampleFIFO& operator=(const SampleFIFO &other);
+
         /** Destructor */
         virtual ~SampleFIFO();
 
