@@ -45,7 +45,7 @@ namespace Kwave
         AmplifyFreePlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~AmplifyFreePlugin() Q_DECL_OVERRIDE;
+        ~AmplifyFreePlugin() override;
 
         /**
          * Shows a dialog for editing the amplification curve and emits a
@@ -53,25 +53,25 @@ namespace Kwave
          * @see Kwave::Plugin::setup
          */
         virtual QStringList *setup(QStringList &previous_params)
-        Q_DECL_OVERRIDE;
+        override;
 
         /**
          * Does the fade operation
          * @param params list of strings with parameters
          */
-        virtual void run(QStringList params) Q_DECL_OVERRIDE;
+        void run(QStringList params) override;
 
         /**
          * @see Kwave::Plugin::start(),
          * overloaded to get the action name from the parameters
          */
-        virtual int start(QStringList &params) Q_DECL_OVERRIDE;
+        int start(QStringList &params) override;
 
         /**
          * Returns a text for the progress dialog if enabled.
          * (already be localized)
          */
-        virtual QString progressText() Q_DECL_OVERRIDE;
+        QString progressText() override;
 
     protected:
 
