@@ -21,7 +21,6 @@
 #include "config.h"
 
 #include <QList>
-#include <QPair>
 
 #include <id3/globals.h>
 
@@ -47,7 +46,8 @@ namespace Kwave
             ENC_TEXT_URL,       /**< URL                               */
             ENC_TEXT_PARTINSET, /**< part in set (x/y)                 */
             ENC_TEXT_TIMESTAMP, /**< ISO 8601 timestamp                */
-            ENC_TRACK_NUM       /**< track/tracks (x/y)                */
+            ENC_TRACK_NUM,      /**< track/tracks (x/y)                */
+            ENC_BINARY          /**< binary/custom data                */
         } Encoding;
 
         /** Default constructor, with initializing */
