@@ -100,7 +100,7 @@ void Kwave::NormalizePlugin::run(QStringList params)
     Kwave::MultiTrackWriter sink(signalManager(), tracks, Kwave::Overwrite,
         first, last);
     Kwave::MultiTrackSource<Kwave::Normalizer, true> normalizer(
-        tracks.count(), this);
+        static_cast<unsigned int>(tracks.count()), this);
 
     // break if aborted
     if (!sink.tracks()) return;
@@ -165,8 +165,8 @@ double Kwave::NormalizePlugin::getMaxPower(Kwave::MultiTrackReader &source)
             if (reader->eof()) continue;
 
             synchronizer.addFuture(QtConcurrent::run(
-                this,
                 &Kwave::NormalizePlugin::getMaxPowerOfTrack,
+                this,
                 reader, &(average[t]), window_size
             ));
         }
@@ -239,3 +239,5 @@ void Kwave::NormalizePlugin::getMaxPowerOfTrack(
 #include "NormalizePlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_NormalizePlugin.cpp"
