@@ -98,13 +98,13 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
      m_supported_resolutions(), m_buffer_progress_count(0),
      m_buffer_progress_total(0), m_buffer_progress_timer(this),
      m_record_enabled(true), m_samples_recorded(0),
-     m_enable_setDevice(true), m_state_icon_widget(Q_NULLPTR)
+     m_enable_setDevice(true), m_state_icon_widget(nullptr)
 {
-    m_status_bar.m_state           = Q_NULLPTR;
-    m_status_bar.m_time            = Q_NULLPTR;
-    m_status_bar.m_sample_rate     = Q_NULLPTR;
-    m_status_bar.m_bits_per_sample = Q_NULLPTR;
-    m_status_bar.m_tracks          = Q_NULLPTR;
+    m_status_bar.m_state           = nullptr;
+    m_status_bar.m_time            = nullptr;
+    m_status_bar.m_sample_rate     = nullptr;
+    m_status_bar.m_bits_per_sample = nullptr;
+    m_status_bar.m_tracks          = nullptr;
 
     setupUi(this);
 
@@ -113,9 +113,9 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
 
     /* set the icons of the record control buttons */
     btNew->setIcon(   QIcon::fromTheme(_("document-new")));
-    btStop->setIcon(  QIcon::fromTheme(_("kwave_player_stop")));
-    btPause->setIcon( QIcon::fromTheme(_("kwave_player_pause")));
-    btRecord->setIcon(QIcon::fromTheme(_("kwave_player_record")));
+    btStop->setIcon(  QIcon::fromTheme(_("media-playback-stop")));
+    btPause->setIcon( QIcon::fromTheme(_("media-playback-pause")));
+    btRecord->setIcon(QIcon::fromTheme(_("media-record")));
 
     // fill the combo box with playback methods
     unsigned int index=0;
@@ -192,7 +192,7 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     // "select device..." button
     connect(btSourceSelect, SIGNAL(clicked()),
             this, SLOT(selectRecordDevice()));
-    connect(cbDevice, SIGNAL(activated(QString)),
+    connect(cbDevice, SIGNAL(textActivated(QString)),
             this, SLOT(setDevice(QString)));
 
     // setup controls
@@ -213,7 +213,7 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
 
     connect(cbFormatSampleRate, SIGNAL(editTextChanged(QString)),
             this, SLOT(sampleRateChanged(QString)));
-    connect(cbFormatSampleRate, SIGNAL(activated(QString)),
+    connect(cbFormatSampleRate, SIGNAL(textActivated(QString)),
             this, SLOT(sampleRateChanged(QString)));
 
     connect(sbFormatTracks, SIGNAL(valueChanged(int)),
@@ -302,7 +302,7 @@ Kwave::RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     tabRecord->setCurrentIndex(1);
     QWidget *page = tabRecord->currentWidget();
     tabRecord->setCurrentIndex(0);
-    if (page) delete page;
+    delete page;
 
     // add the "Done" button manually, otherwise it would have "Cancel" semantic
     QPushButton *bt_done =
@@ -411,17 +411,17 @@ void Kwave::RecordDialog::setSupportedDevices(QStringList devices)
 
         // build a tree with all nodes in the list
         foreach (QString dev_id, devices) {
-            QTreeWidgetItem *parent = Q_NULLPTR;
+            QTreeWidgetItem *parent = nullptr;
 
             QStringList list = dev_id.split(_("||"), Qt::KeepEmptyParts);
             foreach (QString token, list) {
-                QTreeWidgetItem *item = Q_NULLPTR;
+                QTreeWidgetItem *item = nullptr;
 
                 // split the icon name from the token
                 QString icon_name;
-                int pos = token.indexOf(QLatin1Char('|'));
+                qsizetype pos = token.indexOf(QLatin1Char('|'));
                 if (pos > 0) {
-                    icon_name = token.mid(pos+1);
+                    icon_name = token.mid(pos + 1);
                     token     = token.left(pos);
                 }
 
@@ -549,7 +549,7 @@ void Kwave::RecordDialog::setDevice(const QString &device)
 
     if (listDevices->isEnabled()) {
         // treeview mode
-        QTreeWidgetItem *node = m_devices_list_map.key(device, Q_NULLPTR);
+        QTreeWidgetItem *node = m_devices_list_map.key(device, nullptr);
         if (node) {
             node->setSelected(true);
             listDevices->scrollToItem(node);
@@ -1095,6 +1095,7 @@ void Kwave::RecordDialog::setState(Kwave::RecordState state)
             enable_trigger  = true;
             pixmaps.push_back(QPixmap(ok_xpm));
             break;
+        DEFAULT_IMPOSSIBLE;
     }
     m_status_bar.m_state->setText(state_text);
     m_state_icon_widget->setPixmaps(pixmaps, animation_time);
@@ -1222,6 +1223,7 @@ void Kwave::RecordDialog::updateBufferState(unsigned int count,
             } else txt = _("");
             break;
         }
+        DEFAULT_IMPOSSIBLE;
     }
     m_status_bar.m_time->setText(txt);
 }
@@ -1365,3 +1367,5 @@ void Kwave::RecordDialog::showDevicePage()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_RecordDialog.cpp"
