@@ -25,7 +25,6 @@
 
 #include "libkwave/Plugin.h"
 #include "libkwave/Sample.h"
-#include "libkwave/SampleArray.h"
 
 namespace Kwave
 {
@@ -47,13 +46,13 @@ namespace Kwave
         SampleRatePlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~SampleRatePlugin() Q_DECL_OVERRIDE;
+        ~SampleRatePlugin() override;
 
         /**
          * changes the sample rate
          * @param params list of strings with parameters
          */
-        virtual void run(QStringList params) Q_DECL_OVERRIDE;
+        void run(QStringList params) override;
 
     protected:
 
